<?php
namespace wcf\acp\form;
use wcf\data\infraction\suspension\InfractionSuspension;
use wcf\data\infraction\suspension\InfractionSuspensionAction;
use wcf\data\object\type\ObjectTypeCache;
use wcf\data\package\PackageCache;
use wcf\form\AbstractForm;
use wcf\system\exception\IllegalLinkException;
use wcf\system\language\I18nHandler;
use wcf\system\WCF;

/**
 * Shows the suspension edit form.
 *
 * @author	Tim Düsterhus
 * @copyright	2001-2012 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.infraction
 * @subpackage	acp.form
 * @category	Community Framework (commercial)
 */
class SuspensionEditForm extends SuspensionAddForm {
	/**
	 * @see	\wcf\acp\form\ACPForm::$activeMenuItem
	 */
	public $activeMenuItem = 'wcf.acp.menu.link.infraction.suspension.list';
	
	/**
	 * suspension id
	 * @var	integer
	 */
	public $suspensionID = 0;
	
	/**
	 * suspension object
	 * @var	wcf\data\infraction\suspension\InfractionSuspension
	 */
	public $suspensionObj = null;
	
	/**
	 * @see	\wcf\page\IPage::readParameters()
	 */
	public function readParameters() {
		if (isset($_REQUEST['id'])) $this->suspensionID = intval($_REQUEST['id']);
		$this->suspensionObj = new InfractionSuspension($this->suspensionID);
		if (!$this->suspensionObj->suspensionID) {
			throw new IllegalLinkException();
		}
		
		$this->objectType = ObjectTypeCache::getInstance()->getObjectType($this->suspensionObj->objectTypeID);
		$this->objectType->getProcessor()->setData(unserialize($this->suspensionObj->suspensionData));
		$this->action = $this->objectType->objectType;
		
		parent::readParameters();
	}
	
	/**
	 * @see	\wcf\form\IForm::save()
	 */
	public function save() {
		AbstractForm::save();
		
		$packageID = PackageCache::getInstance()->getPackageID('com.woltlab.wcf.infraction');
		$this->title = 'wcf.infraction.suspension.title'.$this->suspensionObj->suspensionID;
		if (I18nHandler::getInstance()->isPlainValue('title')) {
			I18nHandler::getInstance()->remove($this->title, $packageID);
			$this->title = I18nHandler::getInstance()->getValue('title');
		}
		else {
			I18nHandler::getInstance()->save('title', $this->title, 'wcf.infraction.suspension', $packageID);
		}
		
		$expires = 0;
		if (!$this->expiresNever) {
			switch ($this->expiresType) {
				case 'hours':
					$expires = $this->expires * 3600;
					break;
				case 'days':
					$expires = $this->expires * 86400;
					break;
				case 'weeks':
					$expires = $this->expires * 86400 * 7;
					break;
			}
		}
		
		// update suspension
		$this->objectAction = new InfractionSuspensionAction(array($this->suspensionID), 'update', array('data' => array(
			'title' => $this->title,
			'points' => $this->points,
			'expires' => $expires
		)));
		$this->objectAction->executeAction();
		
		$this->saved();
		
		// show success
		WCF::getTPL()->assign(array(
			'success' => true
		));
	}
	
	/**
	 * @see	\wcf\page\IPage::readData()
	 */
	public function readData() {
		parent::readData();
		
		if (!count($_POST)) {
			I18nHandler::getInstance()->setOptions('title', PackageCache::getInstance()->getPackageID('com.woltlab.wcf.infraction'), $this->suspensionObj->title, 'wcf.infraction.suspension.title\d+');
			
			$this->title = $this->suspensionObj->title;
			$this->points = $this->suspensionObj->points;
			if ($this->suspensionObj->expires) {
				$this->expiresNever = 0;
				if (!($this->suspensionObj->expires % (86400 * 7))) {
					$this->expires = $this->suspensionObj->expires / (86400 * 7);
					$this->expiresType = 'weeks';
				}
				else if (!($this->suspensionObj->expires % 86400)) {
					$this->expires = $this->suspensionObj->expires / 86400;
					$this->expiresType = 'days';
				}
				else {
					$this->expires = intval($this->suspensionObj->expires / 3600);
					$this->expiresType = 'hours';
				}
			}
		}
	}
	
	/**
	 * @see	\wcf\page\IPage::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		I18nHandler::getInstance()->assignVariables((bool) count($_POST));
		
		WCF::getTPL()->assign(array(
			'suspensionID' => $this->suspensionID,
			'action' => 'edit'
		));
	}
}