<?php
namespace wcf\acp\form;
use wcf\data\infraction\warning\InfractionWarning;
use wcf\data\infraction\warning\InfractionWarningAction;
use wcf\data\package\PackageCache;
use wcf\form\AbstractForm;
use wcf\system\exception\IllegalLinkException;
use wcf\system\language\I18nHandler;
use wcf\system\WCF;

/**
 * Shows the warning edit form.
 *
 * @author	Tim Duesterhus
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.infraction
 * @subpackage	acp.form
 * @category	Community Framework (commercial)
 */
class WarningEditForm extends WarningAddForm {
	/**
	 * @see	\wcf\acp\form\ACPForm::$activeMenuItem
	 */
	public $activeMenuItem = 'wcf.acp.menu.link.infraction.warning.list';
	
	/**
	 * warning id
	 * @var	integer
	 */
	public $warningID = 0;
	
	/**
	 * warning object
	 * @var	wcf\data\infraction\warning\InfractionWarning
	 */
	public $warningObj = null;
	
	/**
	 * @see	\wcf\page\IPage::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		if (isset($_REQUEST['id'])) $this->warningID = intval($_REQUEST['id']);
		$this->warningObj = new InfractionWarning($this->warningID);
		if (!$this->warningObj->warningID) {
			throw new IllegalLinkException();
		}
	}
	
	/**
	 * @see	\wcf\form\IForm::save()
	 */
	public function save() {
		AbstractForm::save();
		
		$packageID = PackageCache::getInstance()->getPackageID('com.woltlab.wcf.infraction');
		$this->title = 'wcf.infraction.warning.title'.$this->warningObj->warningID;
		if (I18nHandler::getInstance()->isPlainValue('title')) {
			I18nHandler::getInstance()->remove($this->title, $packageID);
			$this->title = I18nHandler::getInstance()->getValue('title');
		}
		else {
			I18nHandler::getInstance()->save('title', $this->title, 'wcf.infraction.warning', $packageID);
		}
		
		$expires = 0;
		if (!$this->expiresNever) {
			switch ($this->expiresType) {
				case 'hours':
					$expires = $this->expires * 3600;
					break;
				case 'days':
					$expires = $this->expires * 86400;
					break;
				case 'weeks':
					$expires = $this->expires * 86400 * 7;
					break;
			}
		}
		
		// update warning
		$this->objectAction = new InfractionWarningAction(array($this->warningID), 'update', array('data' => array(
			'title' => $this->title,
			'points' => $this->points,
			'expires' => $expires
		)));
		$this->objectAction->executeAction();
		
		$this->saved();
		
		// show success
		WCF::getTPL()->assign(array(
			'success' => true
		));
	}
	
	/**
	 * @see	\wcf\page\IPage::readData()
	 */
	public function readData() {
		parent::readData();
		
		if (!count($_POST)) {
			I18nHandler::getInstance()->setOptions('title', PackageCache::getInstance()->getPackageID('com.woltlab.wcf.infraction'), $this->warningObj->title, 'wcf.infraction.warning.title\d+');
			
			$this->title = $this->warningObj->title;
			$this->points = $this->warningObj->points;
			if ($this->warningObj->expires) {
				$this->expiresNever = 0;
				if (!($this->warningObj->expires % (86400 * 7))) {
					$this->expires = $this->warningObj->expires / (86400 * 7);
					$this->expiresType = 'weeks';
				}
				else if (!($this->warningObj->expires % 86400)) {
					$this->expires = $this->warningObj->expires / 86400;
					$this->expiresType = 'days';
				}
				else {
					$this->expires = intval($this->warningObj->expires / 3600);
					$this->expiresType = 'hours';
				}
			}
		}
	}
	
	/**
	 * @see	\wcf\page\IPage::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		I18nHandler::getInstance()->assignVariables((bool) count($_POST));
		
		WCF::getTPL()->assign(array(
			'warningID' => $this->warningID,
			'action' => 'edit'
		));
	}
}