<?php
namespace wcf\acp\page;
use wcf\data\infraction\suspension\InfractionSuspensionList;
use wcf\data\user\User;
use wcf\page\SortablePage;
use wcf\system\menu\acp\ACPMenu;
use wcf\system\WCF;
use wcf\util\StringUtil;

/**
 * Lists active suspensions.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.infraction
 * @subpackage	acp.page
 * @category	Community Framework (commercial)
 */
class UserSuspensionListPage extends SortablePage {
	/**
	 * @see wcf\page\AbstractPage::$neededPermissions
	 */
	public $neededPermissions = array('admin.user.infraction.canManageSuspension');
	
	/**
	 * @see wcf\page\AbstractPage::$neededModules
	 */
	public $neededModules = array('MODULE_USER_INFRACTION');
	
	/**
	 * @see	wcf\page\MultipleLinkPage::$objectListClassName
	 */
	public $objectListClassName = 'wcf\data\user\infraction\suspension\ViewableUserInfractionSuspensionList';
	
	/**
	 * @see	wcf\page\MultipleLinkPage::$defaultSortField
	 */
	public $defaultSortField = 'time';
	
	/**
	 * @see	wcf\page\MultipleLinkPage::$defaultSortField
	 */
	public $defaultSortOrder = 'DESC';
	
	/**
	 * @see	wcf\page\MultipleLinkPage::$validSortFields
	 */
	public $validSortFields = array('userSuspensionID', 'suspensionID', 'userID', 'time', 'expires');
	
	/**
	 * username
	 * @var string
	 */
	public $username = '';
	
	/**
	 * id of predefined suspensions 
	 * @var integer
	 */
	public $suspensionID = 0;
	
	/**
	 * suspension status
	 * @var string
	 */
	public $status = '';
	
	/**
	 * list of available prefined suspensions
	 * @var wcf\data\infraction\suspension\InfractionSuspensionList
	 */
	public $availableSuspensions = null;
	
	/**
	 * @see wcf\page\IPage::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		if (isset($_REQUEST['username'])) $this->username = StringUtil::trim($_REQUEST['username']);
		if (isset($_REQUEST['suspensionID'])) $this->suspensionID = intval($_REQUEST['suspensionID']);
		if (isset($_REQUEST['status']) && ($_REQUEST['status'] == 'active' || $_REQUEST['status'] == 'expired')) $this->status = $_REQUEST['status'];
	}
	
	/**
	 * @see wcf\page\MultipleLinkPage::initObjectList()
	 */
	protected function initObjectList() {
		parent::initObjectList();
		
		// apply filter
		if ($this->username) {
			$user = User::getUserByUsername($this->username);
			if ($user->userID) $this->objectList->getConditionBuilder()->add('user_infraction_suspension.userID = ?', array($user->userID));
		}
		if ($this->suspensionID) {
			$this->objectList->getConditionBuilder()->add('user_infraction_suspension.suspensionID = ?', array($this->suspensionID));
		}
		
		if ($this->status == 'active') {
			$this->objectList->getConditionBuilder()->add('(user_infraction_suspension.expires = 0 OR user_infraction_suspension.expires > ?)', array(TIME_NOW));
		}
		else if ($this->status == 'expired') {
			$this->objectList->getConditionBuilder()->add('(user_infraction_suspension.expires > 0 AND user_infraction_suspension.expires < ?)', array(TIME_NOW));
		}
	}
	
	/**
	 * @see wcf\page\IPage::readData()
	 */
	public function readData() {
		parent::readData();
	
		$this->availableSuspensions = new InfractionSuspensionList();
		$this->availableSuspensions->readObjects();
	}
	
	/**
	 * @see wcf\page\IPage::readParameters()
	 */
	public function assignVariables() {
		parent::assignVariables();
	
		WCF::getTPL()->assign(array(
			'username' => $this->username,
			'suspensionID' => $this->suspensionID,
			'status' => $this->status,
			'availableSuspensions' => $this->availableSuspensions
		));
	}
	
	/**
	 * @see wcf\page\IPage::show()
	 */
	public function show() {
		// set active menu item.
		ACPMenu::getInstance()->setActiveMenuItem('wcf.acp.menu.link.infraction.userSuspension.list');
		
		parent::show();
	}
}
