<?php
namespace wcf\acp\page;
use wcf\data\infraction\warning\InfractionWarningList;
use wcf\data\user\User;
use wcf\page\SortablePage;
use wcf\system\menu\acp\ACPMenu;
use wcf\system\WCF;
use wcf\util\StringUtil;

/**
 * Lists active warnings.
 * 
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.infraction
 * @subpackage	acp.page
 * @category	Community Framework (commercial)
 */
class UserWarningListPage extends SortablePage {
	/**
	 * @see wcf\page\AbstractPage::$neededPermissions
	 */
	public $neededPermissions = array('admin.user.infraction.canManageWarning');
	
	/**
	 * @see wcf\page\AbstractPage::$neededModules
	 */
	public $neededModules = array('MODULE_USER_INFRACTION');
	
	/**
	 * @see	wcf\page\MultipleLinkPage::$objectListClassName
	 */
	public $objectListClassName = 'wcf\data\user\infraction\warning\ViewableUserInfractionWarningList';
	
	/**
	 * @see	wcf\page\MultipleLinkPage::$defaultSortField
	 */
	public $defaultSortField = 'time';
	
	/**
	 * @see	wcf\page\MultipleLinkPage::$defaultSortField
	 */
	public $defaultSortOrder = 'DESC';
	
	/**
	 * @see	wcf\page\MultipleLinkPage::$validSortFields
	 */
	public $validSortFields = array('userWarningID', 'title', 'userID', 'judgeID', 'time', 'points', 'expires');
	
	/**
	 * username
	 * @var string
	 */
	public $username = '';
	
	/**
	 * judge's username
	 * @var string
	 */
	public $judge = '';
	
	/**
	 * id of predefined warning 
	 * @var integer
	 */
	public $warningID = 0;
	
	/**
	 * warning status
	 * @var string
	 */
	public $status = '';
	
	/**
	 * list of available prefined warnings
	 * @var wcf\data\infraction\warning\InfractionWarningList
	 */
	public $availableWarnings = null;
	
	/**
	 * @see wcf\page\IPage::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		if (isset($_REQUEST['username'])) $this->username = StringUtil::trim($_REQUEST['username']);
		if (isset($_REQUEST['judge'])) $this->judge = StringUtil::trim($_REQUEST['judge']);
		if (isset($_REQUEST['warningID'])) $this->warningID = intval($_REQUEST['warningID']);
		if (isset($_REQUEST['status']) && ($_REQUEST['status'] == 'active' || $_REQUEST['status'] == 'expired')) $this->status = $_REQUEST['status'];
	}
	
	/**
	 * @see wcf\page\MultipleLinkPage::initObjectList()
	 */
	protected function initObjectList() {
		parent::initObjectList();
		
		// apply filter
		if ($this->username) {
			$user = User::getUserByUsername($this->username);
			if ($user->userID) $this->objectList->getConditionBuilder()->add('user_infraction_warning.userID = ?', array($user->userID));
		}
		if ($this->judge) {
			$judge = User::getUserByUsername($this->judge);
			if ($judge->userID) $this->objectList->getConditionBuilder()->add('user_infraction_warning.judgeID = ?', array($judge->userID));
		}
		if ($this->warningID) {
			$this->objectList->getConditionBuilder()->add('user_infraction_warning.warningID = ?', array($this->warningID));
		}
		
		if ($this->status == 'active') {
			$this->objectList->getConditionBuilder()->add('(user_infraction_warning.expires = 0 OR user_infraction_warning.expires > ?)', array(TIME_NOW));
		}
		else if ($this->status == 'expired') {
			$this->objectList->getConditionBuilder()->add('(user_infraction_warning.expires > 0 AND user_infraction_warning.expires < ?)', array(TIME_NOW));
		}
	}
	
	/**
	 * @see wcf\page\IPage::readData()
	 */
	public function readData() {
		parent::readData();
	
		$this->availableWarnings = new InfractionWarningList();
		$this->availableWarnings->readObjects();
	}
	
	/**
	 * @see wcf\page\IPage::readParameters()
	 */
	public function assignVariables() {
		parent::assignVariables();
	
		WCF::getTPL()->assign(array(
			'username' => $this->username,
			'judge' => $this->judge,
			'warningID' => $this->warningID,
			'status' => $this->status,
			'availableWarnings' => $this->availableWarnings
		));
	}
	
	/**
	 * @see wcf\page\IPage::show()
	 */
	public function show() {
		// set active menu item.
		ACPMenu::getInstance()->setActiveMenuItem('wcf.acp.menu.link.infraction.userWarning.list');
		
		parent::show();
	}
}
