<?php
namespace wcf\data\infraction\suspension;
use wcf\data\user\infraction\suspension\UserInfractionSuspensionList;
use wcf\data\DatabaseObjectEditor;
use wcf\system\exception\SystemException;
use wcf\system\WCF;

/**
 * An editor for infraction suspensions.
 * 
 * @author	Tim Düsterhus
 * @copyright	2001-2012 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.moderatedUserGroup
 * @subpackage	data.infraction.suspension
 * @category	Community Framework (commercial)
 */
class InfractionSuspensionEditor extends DatabaseObjectEditor {
	/**
	 * @see	\wcf\data\DatabaseObjectDecorator::$baseClass
	 */
	protected static $baseClass = 'wcf\data\infraction\suspension\InfractionSuspension';
	
	/**
	 * @see wcf\data\DatabaseObjectEditor::deleteAll()
	 */
	public static function deleteAll(array $objectIDs = array()) {
		WCF::getDB()->beginTransaction();
		$suspensionList = new InfractionSuspensionList();
		$suspensionList->getConditionBuilder()->add('suspensionID IN(?)', array($objectIDs));
		$suspensionList->readObjects();
		
		$userSuspensionList = new UserInfractionSuspensionList();
		$userSuspensionList->getConditionBuilder()->add('suspensionID IN(?)', array($objectIDs));
		$userSuspensionList->readObjects();
		
		// revoke user suspensions when this suspension is deleted
		foreach ($userSuspensionList as $userSuspension) {
			$suspension = $suspensionList->search($userSuspension->suspensionID);
			if (($action = $suspension->getAction()) === null) {
				throw new SystemException('Unable to delete suspension #'.$suspension->suspensionID.' as action is not available');
			}
			
			$action->unsuspend($suspension, $userSuspension);
		}
		
		$result = parent::deleteAll($objectIDs);
		// parent::deleteAll will commit the transaction, but just to be sure in case it changes
		WCF::getDB()->commitTransaction();
		return $result;
	}
}
