<?php
namespace wcf\data\user\infraction\suspension;
use wcf\data\infraction\suspension\InfractionSuspensionList;
use wcf\data\user\User;
use wcf\data\AbstractDatabaseObjectAction;
use wcf\system\exception\PermissionDeniedException;
use wcf\system\exception\SystemException;
use wcf\system\exception\UserInputException;
use wcf\system\exception\ValidateActionException;
use wcf\system\WCF;

/**
 * Executes actions on an user infraction suspensions.
 * 
 * @author	Tim Duesterhus
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.infraction
 * @subpackage	data.user.infraction.suspension
 * @category	Community Framework (commercial)
 */
class UserInfractionSuspensionAction extends AbstractDatabaseObjectAction {
	/**
	 * @see	\wcf\data\AbstractDatabaseObjectAction::$className
	 */
	protected $className = 'wcf\data\user\infraction\suspension\UserInfractionSuspensionEditor';
	
	/**
	 * user object
	 * @var	wcf\data\user\User
	 */
	public $user = null;
	
	/**
	 * Checks permissions for revoking suspensions.
	 */
	public function validateRevoke() {
		WCF::getSession()->checkPermissions(array('admin.user.infraction.canManageSuspension'));
		
		unset($this->parameters['revoker']);
	}
	
	/**
	 * Revokes suspensions.
	 */
	public function revoke() {
		// revoker cannot be set during an AJAX request but will be 'null' within the cronjob
		if (!isset($this->parameters['revoker'])) {
			$this->parameters['revoker'] = WCF::getUser()->userID;
		}
		
		$objectAction = new UserInfractionSuspensionAction($this->objectIDs, 'update', array(
			'data' => array(
				'revoked' => 1,
				'revoker' => $this->parameters['revoker']
			)
		));
		$objectAction->executeAction();
		
		$suspensionList = new InfractionSuspensionList();
		$suspensionList->getConditionBuilder()->add('suspensionID IN(?)', array($this->objectIDs));
		$suspensionList->readObjects();
		
		$this->readObjects();
		
		// revoke user suspensions when this suspension is deleted
		foreach ($this->objects as $userSuspensionEditor) {
			$userSuspension = $userSuspensionEditor->getDecoratedObject();
			
			$suspension = $suspensionList->search($userSuspension->suspensionID);
			if (($action = $suspension->getAction()) === null) {
				throw new SystemException('Unable to delete suspension #'.$suspension->suspensionID.' as action is not available');
			}
			
			$action->unsuspend($suspension, $userSuspension);
		}
	}
}
