<?php
namespace wcf\data\user\infraction\warning;
use wcf\data\infraction\warning\InfractionWarning;
use wcf\data\object\type\ObjectType;
use wcf\data\object\type\ObjectTypeCache;
use wcf\data\user\User;
use wcf\data\DatabaseObject;
use wcf\system\infraction\warning\IWarnableObject;
use wcf\system\WCF;

/**
 * Represents a warning.
 * 
 * @author	Tim Duesterhus
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.infraction
 * @subpackage	data.user.infraction.warning
 * @category	Community Framework (commercial)
 */
class UserInfractionWarning extends DatabaseObject {
	/**
	 * @see	\wcf\data\DatabaseObject::$databaseTableName
	 */
	protected static $databaseTableName = 'user_infraction_warning';
	
	/**
	 * @see	\wcf\data\DatabaseObject::$databaseTableIndexName
	 */
	protected static $databaseTableIndexName = 'userWarningID';

	/**
	 * warning this user warning is based on
	 * @var	wcf\data\infraction\warning\InfractionWarning
	 */
	protected $suspension = null;
	
	/**
	 * warned user
	 * @var wcf\data\user\User
	 */
	protected $user = null;
	
	/**
	 * judge
	 * @var wcf\data\user\User
	 */
	protected $judge = null;
	
	/**
	 * warned object
	 * @var wcf\system\infraction\warning\IWarnableObject
	 */
	protected $object = false;
	
	/**
	 * Returns the warned object.
	 *
	 * @return	wcf\system\infraction\warning\IWarnableObject
	 */
	public function getObject() {
		if ($this->objectTypeID === null) return null;
		if ($this->object === false) {
			$provider = ObjectTypeCache::getInstance()->getObjectType($this->objectTypeID)->getProcessor();
			
			$this->object = $provider->getObjectByID($this->objectID);
			
			if (!$this->object->getObjectID()) $this->object = null;
		}
		
		return $this->object;
	}
	
	/**
	 * Returns the suspension this user suspension is based on.
	 *
	 * @return	wcf\data\infraction\warning\InfractionWarning
	 */
	public function getWarning() {
		if ($this->warning === null) $this->warning = new InfractionWarning($this->warningID);
		
		return $this->warning;
	}
	
	/**
	 * Returns the warned user.
	 *
	 * @return	wcf\data\user\User
	 */
	public function getUser() {
		if ($this->user === null) $this->user = new User($this->userID);
	
		return $this->user;
	}

	/**
	 * Returns the judge.
	 *
	 * @return	wcf\data\user\User
	 */
	public function getJudge() {
		if ($this->judge === null) $this->judge = new User($this->judgeID);
	
		return $this->judge;
	}
	
	/**
	 * Returns the appropriate warning for the given object and user.
	 * 
	 * @param	wcf\data\user\User				$user
	 * @param	wcf\data\object\type\ObjectType			$objectType
	 * @param	wcf\system\infraction\warning\IWarnableObject	$object
	 * @return	wcf\data\user\infraction\warning\UserInfractionWarning
	 */
	public static function getWarningByUserAndObject(User $user, ObjectType $objectType, IWarnableObject $object) {
		$sql = "SELECT	*
			FROM	wcf".WCF_N."_".self::$databaseTableName."
			WHERE		userID = ?
				AND	objectTypeID = ?
				AND	objectID = ?";
		$statement = WCF::getDB()->prepareStatement($sql);
		$statement->execute(array($user->userID, $objectType->objectTypeID, $object->getObjectID()));
		$row = $statement->fetchArray();
		if(!$row) $row = array();
		
		return new self(null, $row);
	}
}
