<?php
namespace wcf\system\cronjob;
use wcf\data\cronjob\Cronjob;
use wcf\data\infraction\suspension\InfractionSuspensionList;
use wcf\data\user\infraction\suspension\UserInfractionSuspensionAction;
use wcf\data\user\infraction\suspension\UserInfractionSuspensionList;
use wcf\data\user\infraction\warning\UserInfractionWarningAction;
use wcf\data\user\infraction\warning\UserInfractionWarningList;
use wcf\system\exception\SystemException;
use wcf\system\WCF;

/**
 * Revokes expired suspensions and expired warnings.
 * 
 * @author	Tim Duesterhus
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.moderatedUserGroup
 * @subpackage	system.cronjob
 * @category	Community Framework (commercial)
 */
class InfractionCleanupCronjob implements ICronjob {
	/**
	 * @see wcf\system\ICronjob::execute()
	 */
	public function execute(Cronjob $cronjob) {
		if (!MODULE_USER_INFRACTION) return;
		
		// revoke suspensions
		WCF::getDB()->beginTransaction();
		$userSuspensionList = new UserInfractionSuspensionList();
		$userSuspensionList->getConditionBuilder()->add('revoked = ?', array(0));
		$userSuspensionList->getConditionBuilder()->add('expires < ?', array(TIME_NOW));
		$userSuspensionList->getConditionBuilder()->add('expires > ?', array(0));
		$userSuspensionList->readObjects();
		
		$suspensionIDs = array();
		foreach ($userSuspensionList as $userSuspension) {
			$suspensionIDs[] = $userSuspension->suspensionID;
		}
		
		if (empty($suspensionIDs)) {
			WCF::getDB()->rollBackTransaction();
			return;
		}
		
		$userSuspensionAction = new UserInfractionSuspensionAction($userSuspensionList->getObjectIDs(), 'revoke', array(
			'revoker' => null
		));
		$userSuspensionAction->executeAction();
		
		WCF::getDB()->commitTransaction();
		
		// revoke warnings
		WCF::getDB()->beginTransaction();
		$userWarningList = new UserInfractionSuspensionList();
		$userWarningList->getConditionBuilder()->add('revoked = ?', array(0));
		$userWarningList->getConditionBuilder()->add('expires < ?', array(TIME_NOW));
		$userWarningList->getConditionBuilder()->add('expires > ?', array(0));
		$userWarningList->readObjects();
		
		$userWarningAction = new UserInfractionWarningAction($userWarningList->getObjectIDs(), 'revoke', array(
			'revoker' => null
		));
		$userWarningAction->executeAction();
		WCF::getDB()->commitTransaction();
	}
}
