<?php
namespace wcf\system\infraction\suspension;
use wcf\data\infraction\suspension\InfractionSuspension;
use wcf\data\user\infraction\suspension\UserInfractionSuspension;
use wcf\data\user\group\UserGroup;
use wcf\data\user\User;
use wcf\data\user\UserAction;
use wcf\system\exception\UserInputException;
use wcf\system\WCF;

/**
 * Adds the user to a group.
 * 
 * @author	Tim Duesterhus
 * @copyright	2001-2012 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.infraction
 * @subpackage	system.infraction.suspension
 * @category	Community Framework (commercial)
 */
class AddToGroupSuspensionAction extends AbstractSuspensionAction {
	/**
	 * @see wcf\system\infraction\suspension\AbstractSuspensionAction::$data
	 */
	public $data = array('groupID' => 0);
	
	/**
	 * @see wcf\system\infraction\suspension\ISuspensionAction::suspend()
	 */
	public function suspend(InfractionSuspension $suspension, UserInfractionSuspension $userSuspension) {
		$data = unserialize($suspension->suspensionData);
		$user = new User($userSuspension->userID);
		
		// group may have been deleted in the meantime / or become an admin group
		$group = new UserGroup($data['groupID']);
		if (!$group->groupID || $group->isAdminGroup()) return;
		
		$groups = $user->getGroupIDs();
		$groups[] = $group->groupID;
		
		$data = array(
			'groups' => $groups
		);
		$objectAction = new UserAction(array($user->userID), 'update', $data);
		$objectAction->executeAction();
	}
	
	/**
	 * @see wcf\system\infraction\suspension\ISuspensionAction::unsuspend()
	 */
	public function unsuspend(InfractionSuspension $suspension, UserInfractionSuspension $userSuspension) {
		$data = unserialize($suspension->suspensionData);
		
		$data = array(
			'removeGroups' => array($data['groupID'])
		);
		
		$objectAction = new UserAction(array($userSuspension->userID), 'update', $data);
		$objectAction->executeAction();
	}
	
	/**
	 * @see wcf\system\infraction\suspension\ISuspensionAction::readFormParameters()
	 */
	public function readFormParameters() {
		if (isset($_POST['suspensionGroupID'])) $this->data['groupID'] = intval($_POST['suspensionGroupID']);
	}
	
	/**
	 * @see wcf\system\infraction\suspension\ISuspensionAction::validate()
	 */
	public function validate() {
		$group = new UserGroup($this->data['groupID']);
		if (!$group->groupID) throw new UserInputException('suspensionGroupID', 'invalid');
	}
	
	/**
	 * @see wcf\system\infraction\suspension\ISuspensionAction::assignVariables()
	 */
	public function assignVariables() {
		$groups = UserGroup::getGroupsByType(array(UserGroup::OTHER));
		foreach ($groups as $key => $group) {
			if ($group->isAdminGroup()) unset($groups[$key]);
		}
		
		WCF::getTPL()->assign(array(
			'suspensionGroupID' => $this->data['groupID'],
			'groups' => $groups
		));
	}
	
	/**
	 * @see wcf\system\infraction\suspension\ISuspensionAction::getTemplateName()
	 */
	public function getTemplateName() {
		return 'addToGroupSuspensionAction';
	}
}
