<?php
namespace wcf\system\infraction\suspension;
use wcf\data\infraction\suspension\InfractionSuspension;
use wcf\data\user\infraction\suspension\UserInfractionSuspension;

/**
 * Every SuspensionAction has to implement this interface.
 * 
 * @author	Tim Düsterhus
 * @copyright	2001-2012 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.infraction
 * @subpackage	system.infraction.suspension
 * @category	Community Framework (commercial)
 */
interface ISuspensionAction {
	/**
	 * Suspends the user.
	 * 
	 * @param	wcf\data\infraction\suspension\InfractionSuspension		$suspension	The suspension the userSuspension is based on.
	 * @param	wcf\data\user\infraction\suspension\UserInfractionSuspension	$userSuspension	The user suspension
	 */
	public function suspend(InfractionSuspension $suspension, UserInfractionSuspension $userSuspension);
	
	/**
	 * Unsuspends the user.
	 * 
	 * @param	wcf\data\infraction\suspension\InfractionSuspension		$suspension	The suspension the userSuspension is based on.
	 * @param	wcf\data\user\infraction\suspension\UserInfractionSuspension	$userSuspension	The user suspension
	 */
	public function unsuspend(InfractionSuspension $suspension, UserInfractionSuspension $userSuspension);
	
	// form methods
	/**
	 * @see wcf\form\IForm::readFormParameters()
	 */
	public function readFormParameters();
	
	/**
	 * @see wcf\form\IForm::validate()
	 */
	public function validate();
	
	/**
	 * Returns the specific data to save.
	 * 
	 * @return array
	 */
	public function getData();
	
	/**
	 * Reinitializes the specific data from an existing save.
	 * 
	 * @param	array	$data
	 */
	public function setData(array $data);
	
	/**
	 * @see wcf\page\IPage::assignVariables()
	 */
	public function assignVariables();
	
	/**
	 * Returns the template of the template shown in the settings.
	 * 
	 * @return string
	 */
	public function getTemplateName();
}