<?php
namespace wcf\system\menu\user\profile\content;
use wcf\data\user\infraction\warning\UserInfractionWarningList;
use wcf\data\user\infraction\warning\ViewableUserInfractionWarningList;
use wcf\system\SingletonFactory;
use wcf\system\WCF;

/**
 * Shows user warning list.
 * 
 * @author	Alexander Ebert
 * @copyright	2001-2013 WoltLab GmbH
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @package	com.woltlab.wcf.infraction
 * @subpackage	system.menu.user.profile.content
 * @category	Community Framework
 */
class WarningUserProfileMenuContent extends SingletonFactory implements IUserProfileMenuContent {
	/**
	 * true if the associated menu item should be visible for the active user
	 * @var boolean
	 */
	protected $visible = null;
	
	/**
	 * @see	wcf\system\menu\user\profile\content\IUserProfileMenuContent::getContent()
	 */
	public function getContent($userID) {
		$userWarningList = new ViewableUserInfractionWarningList();
		$userWarningList->getConditionBuilder()->add("user_infraction_warning.userID = ?", array($userID));
		$userWarningList->sqlOrderBy = "user_infraction_warning.time DESC";
		$userWarningList->readObjects();
		
		WCF::getTPL()->assign(array(
			'warningList' => $userWarningList
		));
		return WCF::getTPL()->fetch('userWarningList');
	}
	
	/**
	 * @see	wcf\system\menu\user\profile\content\IUserProfileMenuContent::isVisible()
	 */
	public function isVisible($userID) {
		if ($this->visible === null) {
			$this->visible = false;
			
			if (WCF::getSession()->getPermission('mod.infraction.warning.canWarn')) {
				// count warnings
				$userWarningList = new UserInfractionWarningList();
				$userWarningList->getConditionBuilder()->add("user_infraction_warning.userID = ?", array($userID));
				if ($userWarningList->countObjects()) $this->visible = true;
			}
		}
		
		return $this->visible;
	}
}
